/****************************************************************************
 ** This file is part of the MAIA (Malagasy Artificial Intelligence Art) Open Project V2.0.
 **
 ** Copyright (C) 2012 ANDRIAMILAMINA Monge.
 ** All rights reserved.
 **
 ** License: GNU GENERAL PUBLIC LICENSE Version 3, 29 June 2007.
 ** Author:  ANDRIAMILAMINA Monge.
 ** Contact: mongemilamina@gmail.com / +261 32 04 309 92.
 ** Year:    2012.
 ** Status:  Student in ISGEI, Madagasikara, Antananarivo.
 ** Domain:  Automatic.
 **
 ** Commercial Usage
 ** Please contact MAIA.
 **
 ** GNU General Public License Usage
 ** This file may be used under the terms of the GNU
 ** General Public License version 3.0 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.  Please review the following information to
 ** ensure the GNU General Public License version 3.0 requirements will be
 ** met: http://www.gnu.org/copyleft/gpl.html.
 **
 ** If you have questions regarding the use of this file, please contact
 ** the Author.
 **
 ****************************************************************************/

#include "picclass.h"
#include "ui_picclass.h"
#include <QString>
#include <QMessageBox>
#include <QIcon>
#include <QEvent>
#include <QCloseEvent>

PicClass::PicClass(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::PicClass)
{
    ui->setupUi(this);

    myActionQuit = new QAction(QIcon(":/qrc_icons/icons/MAIA_icon_Quit.png"), "", this);
    myActionQuit->setIconText("&Quit");
    myActionAboutAndHelp = new QAction(QIcon(":/qrc_icons/icons/MAIA_icon_About.png"), "", this);
    myActionAboutAndHelp->setIconText("&About");

    myUrlLabel = new QLabel("<b><a href='https://www.andriamilamina.skyrock.com'>" + tr("MAIA Website") + "</a></b>", this);
    myUrlLabel->setToolTip(tr("Go to the MAIA website"));
    myUrlLabel->setStatusTip(tr("Go to the MAIA website"));
    myUrlLabel->setOpenExternalLinks(true);

    ui->toolBar->addAction(myActionAboutAndHelp);
    ui->toolBar->addAction(myActionQuit);
    ui->toolBar->addSeparator();
    ui->toolBar->addWidget(myUrlLabel);

    ui->textConfig_16F84A->setText("\n\n\n\n\t\tPlease, Select a register name in the List Box!");
    ui->textConfig_16F877A->setText("\n\n\n\n\t\tPlease, Select a register name in the List Box!");

    connect(ui->boxRegName_16F877A, SIGNAL(activated(QString)), this, SLOT(browse_16F877A()));
    connect(ui->boxRegName_16F84A, SIGNAL(activated(QString)), this, SLOT(browse_16F84A()));
    connect(myActionQuit, SIGNAL(triggered()), this, SLOT(close()));
    connect(myActionAboutAndHelp, SIGNAL(triggered()), this, SLOT(aboutAndHelp()));
}
//##############################################################################################################
//||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
void PicClass::autreReg16F877A(QString nomRegRecu)
{
    nomRegRecu = ui->boxRegName_16F877A->currentText();
    if (nomRegRecu == "CONFIGURATION WORD")
    {
        CONFIG_REG_label = new QLabel();
        CONFIG_REG_label->setWindowTitle("CONFIGURATION WORD Register for PIC(R) 16F877A");
        pixConfig = new QPixmap(":/qrc_icons/icons/16F877A/config.png");
        CONFIG_REG_label->resize(722, 817);
        CONFIG_REG_label->setPixmap(*pixConfig);
        CONFIG_REG_label->show();
        CONFIG_REG_label->move(0, 30);

        ui->lineNameSign_16F877A->setText("CONFIGURATION WORD Register for PIC(R) 16F877A");
        ui->lineAddr_16F877A->clear();
        ui->lineBank_16F877A->clear();

        ui->lineBit0_16F877A->clear();
        ui->lineBit1_16F877A->clear();
        ui->lineBit2_16F877A->clear();
        ui->lineBit3_16F877A->clear();
        ui->lineBit4_16F877A->clear();
        ui->lineBit5_16F877A->clear();
        ui->lineBit6_16F877A->clear();
        ui->lineBit7_16F877A->clear();

        ui->textConfig_16F877A->setText("\n\n\n\n\t\tSee the new window shown!");
    }
    //||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
    else if (nomRegRecu == "SFR Bank0")
    {
        CONFIG_REG_label = new QLabel();
        CONFIG_REG_label->setWindowTitle("Special Function Register Bank0 for PIC(R) 16F877A");
        pixConfig = new QPixmap(":/qrc_icons/icons/16F877A/sfrBank0.png");
        CONFIG_REG_label->resize(840, 820);
        CONFIG_REG_label->setPixmap(*pixConfig);
        CONFIG_REG_label->show();
        CONFIG_REG_label->move(0, 30);


        ui->lineNameSign_16F877A->setText("Special Function Register Bank0 for PIC(R) 16F877A");
        ui->lineAddr_16F877A->clear();
        ui->lineBank_16F877A->clear();

        ui->lineBit0_16F877A->clear();
        ui->lineBit1_16F877A->clear();
        ui->lineBit2_16F877A->clear();
        ui->lineBit3_16F877A->clear();
        ui->lineBit4_16F877A->clear();
        ui->lineBit5_16F877A->clear();
        ui->lineBit6_16F877A->clear();
        ui->lineBit7_16F877A->clear();

        ui->textConfig_16F877A->setText("\n\n\n\n\t\tSee the new window shown!");
    }
    //||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
    else if (nomRegRecu == "SFR Bank1")
    {
        CONFIG_REG_label = new QLabel();
        CONFIG_REG_label->setWindowTitle("Special Function Register Bank1 for PIC(R) 16F877A");
        pixConfig = new QPixmap(":/qrc_icons/icons/16F877A/sfrBank1.png");
        CONFIG_REG_label->resize(837, 808);
        CONFIG_REG_label->setPixmap(*pixConfig);
        CONFIG_REG_label->show();
        CONFIG_REG_label->move(0, 30);

        ui->lineNameSign_16F877A->setText("Special Function Register Bank1 for PIC(R) 16F877A");
        ui->lineAddr_16F877A->clear();
        ui->lineBank_16F877A->clear();

        ui->lineBit0_16F877A->clear();
        ui->lineBit1_16F877A->clear();
        ui->lineBit2_16F877A->clear();
        ui->lineBit3_16F877A->clear();
        ui->lineBit4_16F877A->clear();
        ui->lineBit5_16F877A->clear();
        ui->lineBit6_16F877A->clear();
        ui->lineBit7_16F877A->clear();

        ui->textConfig_16F877A->setText("\n\n\n\n\t\tSee the new window shown!");
    }
    //||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
    else if (nomRegRecu == "SFR Bank2-3")
    {
        CONFIG_REG_label = new QLabel();
        CONFIG_REG_label->setWindowTitle("Special Function Register Bank2-3 for PIC(R) 16F877A");
        pixConfig = new QPixmap(":/qrc_icons/icons/16F877A/sfrBank2-3.png");
        CONFIG_REG_label->resize(836, 829);
        CONFIG_REG_label->setPixmap(*pixConfig);
        CONFIG_REG_label->show();
        CONFIG_REG_label->move(0, 30);

        ui->lineNameSign_16F877A->setText("Special Function Register Bank2-3 for PIC(R) 16F877A");
        ui->lineAddr_16F877A->clear();
        ui->lineBank_16F877A->clear();

        ui->lineBit0_16F877A->clear();
        ui->lineBit1_16F877A->clear();
        ui->lineBit2_16F877A->clear();
        ui->lineBit3_16F877A->clear();
        ui->lineBit4_16F877A->clear();
        ui->lineBit5_16F877A->clear();
        ui->lineBit6_16F877A->clear();
        ui->lineBit7_16F877A->clear();

        ui->textConfig_16F877A->setText("\n\n\n\n\t\tSee the new window shown!");
    }
}
//||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
//##############################################################################################################
//||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
void PicClass::autreReg16F84A(QString nomRegRecu)
{
    nomRegRecu = ui->boxRegName_16F84A->currentText();
    if (nomRegRecu == "CONFIGURATION WORD")
    {
        CONFIG_REG_label = new QLabel();
        CONFIG_REG_label->setWindowTitle("CONFIGURATION WORD Register for PIC(R) 16F84A");
        pixConfig = new QPixmap(":/qrc_icons/icons/16F84A/config.png");
        CONFIG_REG_label->resize(966, 522);
        CONFIG_REG_label->setPixmap(*pixConfig);
        CONFIG_REG_label->show();
        CONFIG_REG_label->move(0, 30);

        ui->lineNameSign_16F84A->setText("CONFIGURATION WORD Register for PIC(R) 16F84A");
        ui->lineAddr_16F84A->clear();
        ui->lineBank_16F84A->clear();

        ui->lineBit0_16F84A->clear();
        ui->lineBit1_16F84A->clear();
        ui->lineBit2_16F84A->clear();
        ui->lineBit3_16F84A->clear();
        ui->lineBit4_16F84A->clear();
        ui->lineBit5_16F84A->clear();
        ui->lineBit6_16F84A->clear();
        ui->lineBit7_16F84A->clear();

        ui->textConfig_16F84A->setText("\n\n\n\n\t\tSee the new window shown!");
    }
    //||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
    else if (nomRegRecu == "SFR Banks")
    {
        CONFIG_REG_label = new QLabel();
        CONFIG_REG_label->setWindowTitle("Special Function Register Bank 0 and 1 for PIC(R) 16F84A");
        pixConfig = new QPixmap(":/qrc_icons/icons/16F84A/sfrBanks.png");
        CONFIG_REG_label->resize(964, 845);
        CONFIG_REG_label->setPixmap(*pixConfig);
        CONFIG_REG_label->show();
        CONFIG_REG_label->move(0, 30);


        ui->lineNameSign_16F84A->setText("Special Function Register Bank 0 and 1 for PIC(R) 16F84A");
        ui->lineAddr_16F84A->clear();
        ui->lineBank_16F84A->clear();

        ui->lineBit0_16F84A->clear();
        ui->lineBit1_16F84A->clear();
        ui->lineBit2_16F84A->clear();
        ui->lineBit3_16F84A->clear();
        ui->lineBit4_16F84A->clear();
        ui->lineBit5_16F84A->clear();
        ui->lineBit6_16F84A->clear();
        ui->lineBit7_16F84A->clear();

        ui->textConfig_16F84A->setText("\n\n\n\n\t\tSee the new window shown!");

    }
}
//||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
//##############################################################################################################
void PicClass::aboutAndHelp()
{
    myAboutText = new QTextEdit(this);//create a textEdit object for about dialog
    myAboutText->setReadOnly(true);
    myAboutText->setText("\tPIC Reg. Browser is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version. \n\n\tPIC Reg. Browser is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details. \n\n\tYou should have received a copy of the GNU General Public License along with PIC Reg. Browser; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA");

    myHelpText = new QTextEdit(this);//create a textEdit object for help dialog
    myHelpText->setReadOnly(true);
    myHelpText->setText("PIC Reg. Browser helps you to browse the large number of registers in PIC devices.\n\nYou just have to pick up a register name in the List Box, and get all informations about the register: (Address(es), Bank(s), Configurations bits...).\n\nAuthor: ANDRIAMILAMINA Monge.\nE-mail: mongemilamina@gmail.com.");

    myTabWidget = new QTabWidget();//no parent, so this is gonna have its own window
    myTabWidget->setWindowFlags(Qt::WindowStaysOnTopHint);//make the tabwidget above other application windows
    myTabWidget->setAttribute(Qt::WA_ShowModal, true);//make the TabWidget Modal
    myTabWidget->insertTab(1, myAboutText, QIcon(":/qrc_icons/icons/MAIA_icon_About.png"), "&About");//adding the appropriate label to the tabBar, with its title
    myTabWidget->insertTab(1, myHelpText, QIcon(":/qrc_icons/icons/MAIA_icon_Help.png"), "&Help");//adding the appropriate label to the tabBar, with its title

    myTabWidget->setWindowTitle("PIC Reg. Browser 1.3, About and Help");
    myTabWidget->setMinimumSize(500, 300);
    myTabWidget->show();
}
//##############################################################################################################
void PicClass::closeEvent(QCloseEvent *ev)//wait for a QCloseEvent *ev signal sent by close button click
{
    if(ev->type() == QEvent::Close)
    {
        QMessageBox::StandardButton reponse;
        reponse = QMessageBox::warning(this, "PIC Reg. Browser 1.3", "Quit the application?", QMessageBox::Cancel | QMessageBox::Yes);
        if (reponse == QMessageBox::Cancel)
        {
            ev->ignore();
            if(this->isHidden())
                this->show();
        }
        else if (reponse == QMessageBox::Yes)
            this->close();
    }
}
//##############################################################################################################
void PicClass::browse_16F877A()
{
    QString contenuCombo;
    contenuCombo = ui->boxRegName_16F877A->currentText();

    if (contenuCombo == ">>> List Box <<<")
    {
        ui->lineNameSign_16F877A->clear();
        ui->lineAddr_16F877A->clear();
        ui->lineBank_16F877A->clear();

        ui->lineBit0_16F877A->clear();
        ui->lineBit1_16F877A->clear();
        ui->lineBit2_16F877A->clear();
        ui->lineBit3_16F877A->clear();
        ui->lineBit4_16F877A->clear();
        ui->lineBit5_16F877A->clear();
        ui->lineBit6_16F877A->clear();
        ui->lineBit7_16F877A->clear();

        ui->textConfig_16F877A->setText("\n\n\n\n\t\tPlease, Select a register name in the List Box!");
    }

    else if (contenuCombo == "STATUS")
    {
        ui->lineNameSign_16F877A->setText("Status register");
        ui->lineAddr_16F877A->setText("03h ; 83h ; 103h ; 183h");
        ui->lineBank_16F877A->setText("0 ; 1 ; 2 ; 3");

        ui->lineBit0_16F877A->setText("C");
        ui->lineBit1_16F877A->setText("DC");
        ui->lineBit2_16F877A->setText("Z");
        ui->lineBit3_16F877A->setText("#PD");
        ui->lineBit4_16F877A->setText("#TO");
        ui->lineBit5_16F877A->setText("RP0");
        ui->lineBit6_16F877A->setText("RP1");
        ui->lineBit7_16F877A->setText("IRP");

        ui->textConfig_16F877A->setText("IRP: Register Bank Select bit (used for indirect addressing)\n"
                                "\t1 = Bank 2, 3 (100h-1FFh)\n"
                                "\t0 = Bank 0, 1 (00h-FFh)\n\n"

                                "RP1:RP0: Register Bank Select bits (used for direct addressing)\n"
                                "\t11 = Bank 3 (180h-1FFh)\n"
                                "\t10 = Bank 2 (100h-17Fh)\n"
                                "\t01 = Bank 1 (80h-FFh)\n"
                                "\t00 = Bank 0 (00h-7Fh)\n"
                                "\tEach bank is 128 bytes.\n\n"

                                "#TO: Time-out bit\n"
                                "\t1 = After power-up, CLRWDT instruction or SLEEP instruction\n"
                                "\t0 = A WDT time-out occurred\n\n"

                                "#PD: Power-down bit\n"
                                "\t1 = After power-up or by the CLRWDT instruction\n"
                                "\t0 = By execution of the SLEEP instruction\n\n"

                                "Z: Zero bit\n"
                                "\t1 = The result of an arithmetic or logic operation is zero\n"
                                "\t0 = The result of an arithmetic or logic operation is not zero\n\n"

                                "DC: Digit carry/borrow bit (ADDWF, ADDLW,SUBLW,SUBWF instructions)(for borrow, the polarity is reversed)\n"
                                "\t1 = A carry-out from the 4th low order bit of the result occurred\n"
                                "\t0 = No carry-out from the 4th low order bit of the result\n\n"

                                "C: Carry/borrow bit (ADDWF, ADDLW,SUBLW,SUBWF instructions)\n"
                                "\t1 = A carry-out from the Most Significant bit of the result occurred\n"
                                "\t0 = No carry-out from the Most Significant bit of the result occurred");
    }
    //||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
    else if (contenuCombo == "CONFIGURATION WORD")
    {
        PicClass::autreReg16F877A("CONFIGURATION WORD");
    }
    //||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
    else if (contenuCombo == "SFR Bank0")
    {
        PicClass::autreReg16F877A("SFR Bank0");
    }
    //||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
    else if (contenuCombo == "SFR Bank1")
    {
        PicClass::autreReg16F877A("SFR Bank1");
    }
    //||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
    else if (contenuCombo == "SFR Bank2-3")
    {
        PicClass::autreReg16F877A("SFR Bank2-3");
    }
    //||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||

    else if (contenuCombo == "OPTION_REG")
    {
        ui->lineNameSign_16F877A->setText("OPTION REGister");
        ui->lineAddr_16F877A->setText("81h ; 181h");
        ui->lineBank_16F877A->setText("1 ; 3");

        ui->lineBit0_16F877A->setText("PS0");
        ui->lineBit1_16F877A->setText("PS1");
        ui->lineBit2_16F877A->setText("PS2");
        ui->lineBit3_16F877A->setText("PSA");
        ui->lineBit4_16F877A->setText("T0SE");
        ui->lineBit5_16F877A->setText("T0CS");
        ui->lineBit6_16F877A->setText("INTEDG");
        ui->lineBit7_16F877A->setText("#RBPU");

        ui->textConfig_16F877A->setText("#RBPU: PORTB Pull-up Enable bit\n"
                                "\t1 = PORTB pull-ups are disabled\n"
                                "\t0 = PORTB pull-ups are enabled by individual port latch values\n\n"

                                "INTEDG: Interrupt Edge Select bit\n"
                                "\t1 = Interrupt on rising edge of RB0/INT pin\n"
                                "\t0 = Interrupt on falling edge of RB0/INT pin\n\n"

                                "T0CS: TMR0 Clock Source Select bit\n"
                                "\t1 = Transition on RA4/T0CKI pin\n"
                                "\t0 = Internal instruction cycle clock (CLKO)\n\n"

                                "T0SE: TMR0 Source Edge Select bit\n"
                                "\t1 = Increment on high-to-low transition on RA4/T0CKI pin\n"
                                "\t0 = Increment on low-to-high transition on RA4/T0CKI pin\n\n"

                                "PSA: Prescaler Assignment bit\n"
                                "\t1 = Prescaler is assigned to the WDT\n"
                                "\t0 = Prescaler is assigned to the Timer0 module\n\n"

                                "PS2:PS0: Prescaler Rate Select bits\n"
                                "\tBit Value\tTMR0 Rate\tWDT Rate\n"
                                "\t000\t1:2\t1:1\n"
                                "\t001\t1:4\t1:2\n"
                                "\t010\t1:8\t1:4\n"
                                "\t011\t1:16\t1:8\n"
                                "\t100\t1:32\t1:16\n"
                                "\t101\t1:64\t1:32\n"
                                "\t110\t1:128\t1:64\n"
                                "\t111\t1:256\t1:128");

    }

    else if (contenuCombo == "INTCON")
    {
        ui->lineNameSign_16F877A->setText("INTerrupts CONtrol register");
        ui->lineAddr_16F877A->setText("0Bh ; 8Bh ; 10Bh ; 18Bh");
        ui->lineBank_16F877A->setText("0 ; 1 ; 2 ; 3");

        ui->lineBit0_16F877A->setText("RBIF");
        ui->lineBit1_16F877A->setText("INTF");
        ui->lineBit2_16F877A->setText("TMR0IF");
        ui->lineBit3_16F877A->setText("RBIE");
        ui->lineBit4_16F877A->setText("INTE");
        ui->lineBit5_16F877A->setText("TMR0IE");
        ui->lineBit6_16F877A->setText("PEIE");
        ui->lineBit7_16F877A->setText("GIE");

        ui->textConfig_16F877A->setText("GIE: Global Interrupt Enable bit\n"
                                "\t1 = Enables all unmasked interrupts\n"
                                "\t0 = Disables all interrupts\n\n"

                                "PEIE: Peripheral Interrupt Enable bit\n"
                                "\t1 = Enables all unmasked peripheral interrupts\n"
                                "\t0 = Disables all peripheral interrupts\n\n"

                                "TMR0IE: TMR0 Overflow Interrupt Enable bit\n"
                                "\t1 = Enables the TMR0 interrupt\n"
                                "\t0 = Disables the TMR0 interrupt\n\n"

                                "INTE: RB0/INT External Interrupt Enable bit\n"
                                "\t1 = Enables the RB0/INT external interrupt\n"
                                "\t0 = Disables the RB0/INT external interrupt\n\n"

                                "RBIE: RB Port Change Interrupt Enable bit\n"
                                "\t1 = Enables the RB port change interrupt\n"
                                "\t0 = Disables the RB port change interrupt\n\n"

                                "TMR0IF: TMR0 Overflow Interrupt Flag bit\n"
                                "\t1 = TMR0 register has overflowed (must be cleared in software)\n"
                                "\t0 = TMR0 register did not overflow\n\n"

                                "INTF: RB0/INT External Interrupt Flag bit\n"
                                "\t1 = The RB0/INT external interrupt occurred (must be cleared in software)\n"
                                "\t0 = The RB0/INT external interrupt did not occur\n\n"

                                "RBIF: RB Port Change Interrupt Flag bit\n"
                                "\t1 = At least one of the RB7:RB4 pins changed state; a mismatch condition will continue to set the "
                                "bit (must be cleared in software).\n"
                                "\t0 = None of the RB7:RB4 pins have changed state");


    }

    else if (contenuCombo == "PIE1")
    {
        ui->lineNameSign_16F877A->setText("Peripheral Interrupts Enable1 register");
        ui->lineAddr_16F877A->setText("8Ch");
        ui->lineBank_16F877A->setText("1");

        ui->lineBit0_16F877A->setText("TMR1IE");
        ui->lineBit1_16F877A->setText("TMR2IE");
        ui->lineBit2_16F877A->setText("CCP1IE");
        ui->lineBit3_16F877A->setText("SSPIE");
        ui->lineBit4_16F877A->setText("TXIE");
        ui->lineBit5_16F877A->setText("RCIE");
        ui->lineBit6_16F877A->setText("ADIE");
        ui->lineBit7_16F877A->setText("PSPIE");

        ui->textConfig_16F877A->setText("PSPIE: Parallel Slave Port Read/Write Interrupt Enable bit\n"
                                "\t1 = Enables the PSP read/write interrupt\n"
                                "\t0 = Disables the PSP read/write interrupt\n\n"

                                "ADIE: A/D Converter Interrupt Enable bit\n"
                                "\t1 = Enables the A/D converter interrupt\n"
                                "\t0 = Disables the A/D converter interrupt\n\n"

                                "RCIE: USART Receive Interrupt Enable bit\n"
                                "\t1 = Enables the USART receive interrupt\n"
                                "\t0 = Disables the USART receive interrupt\n\n"

                                "TXIE: USART Transmit Interrupt Enable bit\n"
                                "\t1 = Enables the USART transmit interrupt\n"
                                "\t0 = Disables the USART transmit interrupt\n\n"

                                "SSPIE: Synchronous Serial Port Interrupt Enable bit\n"
                                "\t1 = Enables the SSP interrupt\n"
                                "\t0 = Disables the SSP interrupt\n\n"

                                "CCP1IE: CCP1 Interrupt Enable bit\n"
                                "\t1 = Enables the CCP1 interrupt\n"
                                "\t0 = Disables the CCP1 interrupt\n\n"

                                "TMR2IE: TMR2 to PR2 Match Interrupt Enable bit\n"
                                "\t1 = Enables the TMR2 to PR2 match interrupt\n"
                                "\t0 = Disables the TMR2 to PR2 match interrupt\n\n"

                                "TMR1IE: TMR1 Overflow Interrupt Enable bit\n"
                                "\t1 = Enables the TMR1 overflow interrupt\n"
                                "\t0 = Disables the TMR1 overflow interrupt");


    }

    else if (contenuCombo == "PIR1")
    {
        ui->lineNameSign_16F877A->setText("Peripheral Interrupts flag Register1");
        ui->lineAddr_16F877A->setText("0Ch");
        ui->lineBank_16F877A->setText("0");

        ui->lineBit0_16F877A->setText("TMR1IF");
        ui->lineBit1_16F877A->setText("TMR2IF");
        ui->lineBit2_16F877A->setText("CCP1IF");
        ui->lineBit3_16F877A->setText("SSPIF");
        ui->lineBit4_16F877A->setText("TXIF");
        ui->lineBit5_16F877A->setText("RCIF");
        ui->lineBit6_16F877A->setText("ADIF");
        ui->lineBit7_16F877A->setText("PSPIF");

        ui->textConfig_16F877A->setText("PSPIF: Parallel Slave Port Read/Write Interrupt Flag bit\n"
                                "\t1 = A read or a write operation has taken place (must be cleared in software)\n"
                                "\t0 = No read or write has occurred\n\n"

                                "ADIF: A/D Converter Interrupt Flag bit\n"
                                "\t1 = An A/D conversion completed\n"
                                "\t0 = The A/D conversion is not complete\n\n"

                                "RCIF: USART Receive Interrupt Flag bit\n"
                                "\t1 = The USART receive buffer is full\n"
                                "\t0 = The USART receive buffer is empty\n\n"

                                "TXIF: USART Transmit Interrupt Flag bit\n"
                                "\t1 = The USART transmit buffer is empty\n"
                                "\t0 = The USART transmit buffer is full\n\n"

                                "SSPIF: Synchronous Serial Port (SSP) Interrupt Flag bit\n"
                                "\t1 = The SSP interrupt condition has occurred and must be cleared in software before returning from the Interrupt Service Routine\n"
                                "\tThe conditions that will set this bit are:\n"
                                "\t\tSPI - A transmission/reception has taken place.\n"
                                "\t\tI2C Slave - A transmission/reception has taken place.\n"
                                "\t\tI2C Master:\n"
                                "\t- A transmission/reception has taken place.\n"
                                "\t- The initiated Start condition was completed by the SSP module.\n"
                                "\t- The initiated Stop condition was completed by the SSP module.\n"
                                "\t- The initiated Restart condition was completed by the SSP module.\n"
                                "\t- The initiated Acknowledge condition was completed by the SSP module.\n"
                                "\t- A Start condition occurred while the SSP module was Idle (multi-master system).\n"
                                "\t- A Stop condition occurred while the SSP module was Idle (multi-master system).\n\n"

                                "\t0 = No SSP interrupt condition has occurred\n\n"

                                "CCP1IF: CCP1 Interrupt Flag bit\n"
                                "\tCapture Mode:\n"
                                "\t1 = A TMR1 register capture occurred (must be cleared in software)\n"
                                "\t0 = No TMR1 register capture occurred\n\n"

                                "\tCompare Mode:\n"
                                "\t1 = A TMR1 register compare match occurred (must be cleared in software)\n"
                                "\t0 = No TMR1 register compare match occurred\n\n"

                                "\tPWM Mode:\n"
                                "\tNot Used in this mode\n\n"

                                "TMR2IF: TMR2 to PR2 Match Interrupt Flag bit\n"
                                "\t1 = TMR2 to PR2 match occurred (must be cleared in software)\n"
                                "\t0 = No TMR2 to PR2 match occurred\n\n"

                                "TMR1IF: TMR1 Overflow Interrupt Flag bit\n"
                                "\t1 = TMR1 register overflowed (must be cleared in software)\n"
                                "\t0 = TMR1 register did not overflow");


    }

    else if (contenuCombo == "PIE2")
    {
        ui->lineNameSign_16F877A->setText("Peripheral Interrupts Enable2 register");
        ui->lineAddr_16F877A->setText("8Dh");
        ui->lineBank_16F877A->setText("1");

        ui->lineBit0_16F877A->setText("CCP2IE");
        ui->lineBit1_16F877A->setText("---");
        ui->lineBit2_16F877A->setText("---");
        ui->lineBit3_16F877A->setText("BCLIE");
        ui->lineBit4_16F877A->setText("EEIE");
        ui->lineBit5_16F877A->setText("---");
        ui->lineBit6_16F877A->setText("CMIE");
        ui->lineBit7_16F877A->setText("---");

        ui->textConfig_16F877A->setText("--- = Unimplemented: Read as '0'\n\n"

                                "CMIE: Comparator Interrupt Enable bit\n"
                                "\t1 = Enables the comparator interrupt\n"
                                "\t0 = Disable the comparator interrupt\n\n"

                                "EEIE: EEPROM Write Operation Interrupt Enable bit\n"
                                "\t1 = Enable EEPROM write interrupt\n"
                                "\t0 = Disable EEPROM write interrupt\n\n"

                                "BCLIE: Bus Collision Interrupt Enable bit\n"
                                "\t1 = Enable bus collision interrupt\n"
                                "\t0 = Disable bus collision interrupt\n\n"

                                "CCP2IE: CCP2 Interrupt Enable bit\n"
                                "\t1 = Enables the CCP2 interrupt\n"
                                "\t0 = Disables the CCP2 interrupt");
    }

    else if (contenuCombo == "PIR2")
    {
        ui->lineNameSign_16F877A->setText("Peripheral Interrupts flag Register2");
        ui->lineAddr_16F877A->setText("0Dh");
        ui->lineBank_16F877A->setText("0");

        ui->lineBit0_16F877A->setText("CCP2IF");
        ui->lineBit1_16F877A->setText("---");
        ui->lineBit2_16F877A->setText("---");
        ui->lineBit3_16F877A->setText("BCLIF");
        ui->lineBit4_16F877A->setText("EEIF");
        ui->lineBit5_16F877A->setText("---");
        ui->lineBit6_16F877A->setText("CMIF");
        ui->lineBit7_16F877A->setText("---");

        ui->textConfig_16F877A->setText("--- = Unimplemented: Read as '0'\n\n"

                                "CMIF: Comparator Interrupt Flag bit\n"
                                "\t1 = The comparator input has changed (must be cleared in software)\n"
                                "\t0 = The comparator input has not changed\n\n"

                                "EEIF: EEPROM Write Operation Interrupt Flag bit\n"
                                "\t1 = The write operation completed (must be cleared in software)\n"
                                "\t0 = The write operation is not complete or has not been started\n\n"

                                "BCLIF: Bus Collision Interrupt Flag bit\n"
                                "\t1 = A bus collision has occurred in the SSP when configured for I2C Master mode\n"
                                "\t0 = No bus collision has occurred\n\n"

                                "CCP2IF: CCP2 Interrupt Flag bit\n"
                                "\tCapture Mode:\n"
                                "\t1 = A TMR1 register capture occurred (must be cleared in software)\n"
                                "\t0 = No TMR1 register capture occurred\n\n"

                                "\tCompare Mode:\n"
                                "\t1 = A TMR1 register compare match occurred (must be cleared in software)\n"
                                "\t0 = No TMR1 register compare match occurred\n\n"

                                "\tPWM Mode:\n"
                                "\tNot Used in this mode");
    }

    else if (contenuCombo == "PCON")
    {
        ui->lineNameSign_16F877A->setText("Power CONtrol register");
        ui->lineAddr_16F877A->setText("8Eh");
        ui->lineBank_16F877A->setText("1");

        ui->lineBit0_16F877A->setText("#BOR");
        ui->lineBit1_16F877A->setText("#POR");
        ui->lineBit2_16F877A->setText("---");
        ui->lineBit3_16F877A->setText("---");
        ui->lineBit4_16F877A->setText("---");
        ui->lineBit5_16F877A->setText("---");
        ui->lineBit6_16F877A->setText("---");
        ui->lineBit7_16F877A->setText("---");

        ui->textConfig_16F877A->setText("--- = Unimplemented: Read as '0'\n\n"

                                "#POR: Power-on Reset Status bit\n"
                                "\t1 = No Power-on Reset occurred\n"
                                "\t0 = A Power-on Reset occurred (must be set in software after a Power-on Reset occurs)\n\n"

                                "#BOR: Brown-out Reset Status bit\n"
                                "\t1 = No Brown-out Reset occurred\n"
                                "\t0 = A Brown-out Reset occurred (must be set in software after a Brown-out Reset occurs)");
    }

    else if (contenuCombo == "T1CON")
    {
        ui->lineNameSign_16F877A->setText("Timer1 CONtrol register");
        ui->lineAddr_16F877A->setText("10h");
        ui->lineBank_16F877A->setText("0");

        ui->lineBit0_16F877A->setText("TMR1ON");
        ui->lineBit1_16F877A->setText("TMR1CS");
        ui->lineBit2_16F877A->setText("#T1SYNC");
        ui->lineBit3_16F877A->setText("T1OSCEN");
        ui->lineBit4_16F877A->setText("T1CKPS0");
        ui->lineBit5_16F877A->setText("T1CKPS1");
        ui->lineBit6_16F877A->setText("---");
        ui->lineBit7_16F877A->setText("---");

        ui->textConfig_16F877A->setText("--- = Unimplemented: Read as '0'\n\n"

                                "T1CKPS1:T1CKPS0: Timer1 Input Clock Prescale Select bits\n"
                                "\t11 = 1:8 prescale value\n"
                                "\t10 = 1:4 prescale value\n"
                                "\t01 = 1:2 prescale value\n"
                                "\t00 = 1:1 prescale value\n\n"

                                "T1OSCEN: Timer1 Oscillator Enable Control bit\n"
                                "\t1 = Oscillator is enabled\n"
                                "\t0 = Oscillator is shut-off (the oscillator inverter is turned off to eliminate power drain)\n\n"

                                "#T1SYNC: Timer1 External Clock Input Synchronization Control bit\n"

                                "\tWhen TMR1CS = 1\n"
                                "\t1 = Do not synchronize external clock input\n"
                                "\t0 = Synchronize external clock input\n\n"

                                "\tWhen TMR1CS = 0:\n"
                                "\tThis bit is ignored. Timer1 uses the internal clock when TMR1CS = 0\n"

                                "TMR1CS: Timer1 Clock Source Select bit\n"
                                "\t1 = External clock from pin RC0/T1OSO/T1CKI (on the rising edge)\n"
                                "\t0 = Internal clock (FOSC/4)\n\n"

                                "TMR1ON: Timer1 On bit\n"
                                "\t1 = Enables Timer1\n"
                                "\t0 = Stops Timer1");
    }


    else if (contenuCombo == "T2CON")
    {
        ui->lineNameSign_16F877A->setText("Timer2 CONtrol register");
        ui->lineAddr_16F877A->setText("12h");
        ui->lineBank_16F877A->setText("0");

        ui->lineBit0_16F877A->setText("T2CKPS0");
        ui->lineBit1_16F877A->setText("T2CKPS1");
        ui->lineBit2_16F877A->setText("TMR2ON");
        ui->lineBit3_16F877A->setText("TOUTPS0");
        ui->lineBit4_16F877A->setText("TOUTPS1");
        ui->lineBit5_16F877A->setText("TOUTPS2");
        ui->lineBit6_16F877A->setText("TOUTPS3");
        ui->lineBit7_16F877A->setText("---");

        ui->textConfig_16F877A->setText("--- = Unimplemented: Read as '0'\n\n"

                                "TOUTPS3:TOUTPS0: Timer2 Output Postscale Select bits\n"
                                "\t0000 = 1:1 postscale\n"
                                "\t0001 = 1:2 postscale\n"
                                "\t0010 = 1:3 postscale\n"
                                "\t... until\n"
                                "\t1111 = 1:16 postscale\n\n"

                                "TMR2ON: Timer2 On bit\n"
                                "\t1 = Timer2 is on\n"
                                "\t0 = Timer2 is off\n\n"

                                "T2CKPS1:T2CKPS0: Timer2 Clock Prescale Select bits\n"
                                "\t00 = Prescaler is 1\n"
                                "\t01 = Prescaler is 4\n"
                                "\t1x = Prescaler is 16");
    }


    else if (contenuCombo == "CCP1CON ;*; CCP2CON")
    {
        ui->lineNameSign_16F877A->setText(" CCP1 ;*; CCP2 CONtrol register");
        ui->lineAddr_16F877A->setText("17h ;*; 1Dh");
        ui->lineBank_16F877A->setText("0");

        ui->lineBit0_16F877A->setText("CCPxM0");
        ui->lineBit1_16F877A->setText("CCPxM1");
        ui->lineBit2_16F877A->setText("CCPxM2");
        ui->lineBit3_16F877A->setText("CCPxM3");
        ui->lineBit4_16F877A->setText("CCPxY");
        ui->lineBit5_16F877A->setText("CCPxX");
        ui->lineBit6_16F877A->setText("---");
        ui->lineBit7_16F877A->setText("---");

        ui->textConfig_16F877A->setText("--- = Unimplemented: Read as '0'\n\n"

                                "CCPxX:CCPxY: PWM Least Significant bits\n"

                                "\tCapture mode:\n"
                                "\tUnused.\n\n"

                                "\tCompare mode:\n"
                                "\tUnused.\n\n"

                                "\tPWM mode:\n"
                                "\tThese bits are the two LSbs of the PWM duty cycle. The eight MSbs are found in CCPRxL\n\n"

                                "CCPxM3:CCPxM0: CCPx Mode Select bits\n"
                                "\t0000 = Capture/Compare/PWM disabled (resets CCPx module)\n"
                                "\t0100 = Capture mode, every falling edge\n"
                                "\t0101 = Capture mode, every rising edge\n"
                                "\t0110 = Capture mode, every 4th rising edge\n"
                                "\t0111 = Capture mode, every 16th rising edge\n"
                                "\t1000 = Compare mode, set output on match (CCPxIF bit is set)\n"
                                "\t1001 = Compare mode, clear output on match (CCPxIF bit is set)\n"
                                "\t1010 = Compare mode, generate software interrupt on match (CCPxIF bit is set, CCPx pin is unaffected)\n"
                                "\t1011 = Compare mode, trigger special event (CCPxIF bit is set, CCPx pin is unaffected);\n"
                                "\t\tCCP1 resets TMR1; CCP2 resets TMR1 and starts an A/D conversion (if A/D module is enabled)\n"

                                "\t11xx = PWM mode");
    }

    else if (contenuCombo == "SSPSTAT (SPI Mode)")
    {
        ui->lineNameSign_16F877A->setText(" Master Synchronous Serial Port STATus register");
        ui->lineAddr_16F877A->setText("94h");
        ui->lineBank_16F877A->setText("1");

        ui->lineBit0_16F877A->setText("BF");
        ui->lineBit1_16F877A->setText("UA");
        ui->lineBit2_16F877A->setText("R/#W");
        ui->lineBit3_16F877A->setText("S");
        ui->lineBit4_16F877A->setText("P");
        ui->lineBit5_16F877A->setText("D/#A");
        ui->lineBit6_16F877A->setText("CKE");
        ui->lineBit7_16F877A->setText("SMP");

        ui->textConfig_16F877A->setText("SMP: Sample bit\n"

                                "\tSPI Master mode:\n"
                                "\t1 = Input data sampled at end of data output time\n"
                                "\t0 = Input data sampled at middle of data output time\n\n"

                                "\tSPI Slave mode:\n"
                                "\tSMP must be cleared when SPI is used in Slave mode\n\n"

                                "\tPWM mode:\n"
                                "\tThese bits are the two LSbs of the PWM duty cycle. The eight MSbs are found in CCPRxL\n\n"

                                "CKE: SPI Clock Select bit\n"
                                "\t1 = Transmit occurs on transition from active to Idle clock state\n"
                                "\t0 = Transmit occurs on transition from Idle to active clock state\n\n"

                                "Note: Polarity of clock state is set by the CKP bit (SSPCON1<4>).\n\n"

                                "D/#A: Data/Address bit\n"
                                "\tUsed in I2C mode only\n\n"

                                "P: Stop bit\n"
                                "\tUsed in I2C mode only. This bit is cleared when the MSSP module is disabled, SSPEN is cleared.\n\n"

                                "S: Start bit\n"
                                "\tUsed in I2C mode only.\n\n"

                                "R/#W: Read/Write bit information\n"
                                "\tUsed in I2C mode only.\n\n"

                                "UA: Update Address bit\n"
                                "\tUsed in I2C mode only.\n\n"

                                "BF: Buffer Full Status bit (Receive mode only)\n"
                                "\t1 = Receive complete, SSPBUF is full\n"
                                "\t0 = Receive not complete, SSPBUF is empty");
    }
    else if (contenuCombo == "SSPCON1 (SPI Mode)")
    {
        ui->lineNameSign_16F877A->setText(" Master Synchronous Serial Port CONtrol1 register");
        ui->lineAddr_16F877A->setText("14h");
        ui->lineBank_16F877A->setText("0");

        ui->lineBit0_16F877A->setText("SSPM0");
        ui->lineBit1_16F877A->setText("SSPM1");
        ui->lineBit2_16F877A->setText("SSPM2");
        ui->lineBit3_16F877A->setText("SSPM3");
        ui->lineBit4_16F877A->setText("CKP");
        ui->lineBit5_16F877A->setText("SSPEN");
        ui->lineBit6_16F877A->setText("SSPOV");
        ui->lineBit7_16F877A->setText("WCOL");

        ui->textConfig_16F877A->setText("WCOL: Write Collision Detect bit (Transmit mode only)\n"
                                "\t1 = The SSPBUF register is written while it is still transmitting the previous word. (Must be cleared in software.)\n"
                                "\t0 = No collision\n\n"

                                "SSPOV: Receive Overflow Indicator bit\n"
                                "\tSPI Slave mode:\n"
                                "\t1 = A new byte is received while the SSPBUF register is still holding the previous data.\n"
                                "\t\tIn case of overflow, the data in SSPSR is lost. Overflow can only occur in Slave mode.\n"
                                "\t\tThe user must read the SSPBUF, even if only transmitting data, to avoid setting overflow.\n"
                                "\t\t(Must be cleared in software.)\n"

                                "\t0 = No overflow\n\n"

                                "Note: In Master mode, the overflow bit is not set,\n"
                                "since each new reception (and transmission) is initiated by writing to the SSPBUF register.\n\n"

                                "SSPEN: Clock Polarity Select bit\n"
                                "\t1 = Enables serial port and configures SCK, SDO, SDI, and SS as serial port pins\n"
                                "\t0 = Disables serial port and configures these pins as I/O port pins\n\n"

                                "Note: When enabled, these pins must be properly configured as input or output.\n\n"

                                "CKP: Clock Polarity Select bit\n"
                                "\t1 = Idle state for clock is a high level\n"
                                "\t0 = Idle state for clock is a low level\n\n"

                                "SSPM3:SSPM0: Synchronous Serial Port Mode Select bits\n"
                                "\t0101 = SPI Slave mode, clock = SCK pin. SS pin control disabled. SS can be used as I/O pin.\n"
                                "\t0100 = SPI Slave mode, clock = SCK pin. SS pin control enabled.\n"
                                "\t0011 = SPI Master mode, clock = TMR2 output/2\n"
                                "\t0010 = SPI Master mode, clock = FOSC/64\n"
                                "\t0001 = SPI Master mode, clock = FOSC/16\n"
                                "\t0000 = SPI Master mode, clock = FOSC/4\n\n"

                                "Note: Bit combinations not specifically listed here are either reserved or implemented in I2C mode only.");
    }

    else if (contenuCombo == "SSPSTAT (I2C Mode)")
    {
        ui->lineNameSign_16F877A->setText(" Master Synchronous Serial Port STATus register");
        ui->lineAddr_16F877A->setText("94h");
        ui->lineBank_16F877A->setText("1");

        ui->lineBit0_16F877A->setText("BF");
        ui->lineBit1_16F877A->setText("UA");
        ui->lineBit2_16F877A->setText("R/#W");
        ui->lineBit3_16F877A->setText("S");
        ui->lineBit4_16F877A->setText("P");
        ui->lineBit5_16F877A->setText("D/#A");
        ui->lineBit6_16F877A->setText("CKE");
        ui->lineBit7_16F877A->setText("SMP");

        ui->textConfig_16F877A->setText("SMP: Slew Rate Control bit\n"

                                "\tIn Master or Slave mode:\n"
                                "\t1 = Slew rate control disabled for standard speed mode (100 kHz and 1 MHz)\n"
                                "\t0 = Slew rate control enabled for high-speed mode (400 kHz)\n\n"

                                "CKE: SMBus Select bit\n"
                                "\tIn Master or Slave mode:\n"
                                "\t1 = Enable SMBus specific inputs\n"
                                "\t0 = Disable SMBus specific inputs\n\n"

                                "D/#A: Data/Address bit\n"
                                "\tIn Master mode:\n"
                                "\tReserved\n\n"

                                "\tIn Slave mode:\n"
                                "\t1 = Indicates that the last byte received or transmitted was data\n"
                                "\t0 = Indicates that the last byte received or transmitted was address\n\n"

                                "P: Stop bit\n"
                                "\t1 = Indicates that a Stop bit has been detected last\n"
                                "\t0 = Stop bit was not detected last\n\n"

                                "Note: This bit is cleared on Reset and when SSPEN is cleared.\n\n"

                                "S: Start bit\n"
                                "\t1 = Indicates that a Start bit has been detected last\n"
                                "\t0 = Start bit was not detected last\n\n"

                                "Note: This bit is cleared on Reset and when SSPEN is cleared.\n\n"

                                "R/#W: Read/Write bit information (I2C mode only)\n"
                                "\tIn Slave mode:\n"
                                "\t1 = Read\n"
                                "\t0 = Write\n\n"

                                "\tIn Master mode:\n"
                                "\t1 = Transmit is in progress\n"
                                "\t0 = Transmit is not in progress\n\n"

                                "UA: Update Address (10-bit Slave mode only)\n"
                                "\t1 = Indicates that the user needs to update the address in the SSPADD register\n"
                                "\t0 = Address does not need to be updated\n\n"

                                "BF: Buffer Full Status bit\n"
                                "\tIn Transmit mode:\n"
                                "\t1 = Receive complete, SSPBUF is full\n"
                                "\t0 = Receive not complete, SSPBUF is empty\n\n"

                                "\tIn Receive mode:\n"
                                "\t1 = Data Transmit in progress (does not include the ACK and Stop bits), SSPBUF is full\n"
                                "\t0 = Data Transmit complete (does not include the ACK and Stop bits), SSPBUF is empty\n\n");
    }

    else if (contenuCombo == "SSPCON1 (I2C Mode)")
    {
        ui->lineNameSign_16F877A->setText(" Master Synchronous Serial Port CONtrol1 register");
        ui->lineAddr_16F877A->setText("14h");
        ui->lineBank_16F877A->setText("0");

        ui->lineBit0_16F877A->setText("SSPM0");
        ui->lineBit1_16F877A->setText("SSPM1");
        ui->lineBit2_16F877A->setText("SSPM2");
        ui->lineBit3_16F877A->setText("SSPM3");
        ui->lineBit4_16F877A->setText("CKP");
        ui->lineBit5_16F877A->setText("SSPEN");
        ui->lineBit6_16F877A->setText("SSPOV");
        ui->lineBit7_16F877A->setText("WCOL");

        ui->textConfig_16F877A->setText("WCOL: Write Collision Detect bit\n"
                                "\tIn Master Transmit mode:\n"
                                "\t1 = A write to the SSPBUF register was attempted while the I2C conditions were not valid for a transmission to be started.\n"
                                "(Must be cleared in software.)\n"

                                "\t0 = No collision\n\n"

                                "\tIn Slave Transmit mode:\n"
                                "\t1 = The SSPBUF register is written while it is still transmitting the previous word. (Must be cleared in"
                                "software.)\n"
                                "\t0 = No collision\n\n"

                                "\tIn Receive mode (Master or Slave modes):\n"
                                "\tThis is a \"don't care\" bit.\n\n"

                                "SSPOV: Receive Overflow Indicator bit\n"
                                "\tIn Receive mode:\n"
                                "\t1 = A byte is received while the SSPBUF register is still holding the previous byte.\n"
                                "\t\t(Must be cleared in software.)\n"
                                "\t0 = No overflow\n\n"

                                "\tIn Transmit mode:\n"
                                "\tThis is a \"don't care\" bit in Transmit mode.\n\n"

                                "SSPEN: Synchronous Serial Port Enable bit\n"
                                "\t1 = Enables the serial port and configures the SDA and SCL pins as the serial port pins\n"
                                "\t0 = Disables the serial port and configures these pins as I/O port pins\n\n"

                                "Note: When enabled, the SDA and SCL pins must be properly configured as input or output.\n\n"

                                "CKP: SCK Release Control bit\n"
                                "\tIn Slave mode:\n"
                                "\t1 = Release clock\n"
                                "\t0 = Holds clock low (clock stretch). (Used to ensure data setup time.)\n\n"

                                "\tIn Master mode:\n"
                                "\tUnused in this mode.\n\n"

                                "SSPM3:SSPM0: Synchronous Serial Port Mode Select bits\n"
                                "\t1111 = I2C Slave mode, 10-bit address with Start and Stop bit interrupts enabled\n"
                                "\t1110 = I2C Slave mode, 7-bit address with Start and Stop bit interrupts enabled\n"
                                "\t1011 = I2C Firmware Controlled Master mode (Slave Idle)\n"
                                "\t1000 = I2C Master mode, clock = FOSC/(4 * (SSPADD + 1))\n"
                                "\t0111 = I2C Slave mode, 10-bit address\n"
                                "\t0110 = I2C Slave mode, 7-bit address\n\n"

                                "Note: Bit combinations not specifically listed here are either reserved or implemented in SPI mode only.");
    }

    else if (contenuCombo == "SSPCON2 (I2C Mode)")
    {
        ui->lineNameSign_16F877A->setText(" Master Synchronous Serial Port CONtrol2 register");
        ui->lineAddr_16F877A->setText("91h");
        ui->lineBank_16F877A->setText("1");

        ui->lineBit0_16F877A->setText("SEN");
        ui->lineBit1_16F877A->setText("RSEN");
        ui->lineBit2_16F877A->setText("PEN");
        ui->lineBit3_16F877A->setText("RCEN");
        ui->lineBit4_16F877A->setText("ACKEN");
        ui->lineBit5_16F877A->setText("ACKDT");
        ui->lineBit6_16F877A->setText("ACKSTAT");
        ui->lineBit7_16F877A->setText("GCEN");

        ui->textConfig_16F877A->setText("GCEN: General Call Enable bit (Slave mode only)\n"
                                "\t1 = Enable interrupt when a general call address (0000h) is received in the SSPSR\n"
                                "\t0 = General call address disabled\n\n"

                                "ACKSTAT: Acknowledge Status bit (Master Transmit mode only)\n"
                                "\t1 = Acknowledge was not received from slave\n"
                                "\t0 = Acknowledge was received from slave\n\n"

                                "ACKDT: Acknowledge Data bit (Master Receive mode only)\n"
                                "\t1 = Not Acknowledge\n"
                                "\t0 = Acknowledge\n\n"

                                "Note: Value that will be transmitted when the user initiates an Acknowledge sequence at the"
                                "end of a receive.\n\n"

                                "ACKEN: Acknowledge Sequence Enable bit (Master Receive mode only)\n"
                                "\t1 = Initiate Acknowledge sequence on SDA and SCL pins and transmit ACKDT data bit.\n"
                                "Automatically cleared by hardware.\n"
                                "\t0 = Acknowledge sequence Idle\n\n"

                                "RCEN: Receive Enable bit (Master mode only)\n"
                                "\t1 = Enables Receive mode for I2C\n"
                                "\t0 = Receive Idle\n\n"

                                "PEN: Stop Condition Enable bit (Master mode only)\n"
                                "\t1 = Initiate Stop condition on SDA and SCL pins. Automatically cleared by hardware.\n"
                                "\t0 = Stop condition Idle\n\n"

                                "RSEN: Repeated Start Condition Enabled bit (Master mode only)\n"
                                "\t1 = Initiate Repeated Start condition on SDA and SCL pins. Automatically cleared by hardware.\n"
                                "\t0 = Repeated Start condition Idle\n\n"

                                "SEN: Repeated Start Condition Enabled bit (Master mode only)\n"
                                "\tIn Master mode:\n"
                                "\t1 = Initiate Start condition on SDA and SCL pins. Automatically cleared by hardware.\n"
                                "\t0 = Start condition Idle\n\n"

                                "\tIn Slave mode:\n"
                                "\t1 = Clock stretching is enabled for both slave transmit and slave receive (stretch enabled)\n"
                                "\t0 = Clock stretching is enabled for slave transmit only (PIC(R) 16F87X compatibility)");
    }

    else if (contenuCombo == "TXSTA")
    {
        ui->lineNameSign_16F877A->setText(" Transmit STAtus and Control register");
        ui->lineAddr_16F877A->setText("98h");
        ui->lineBank_16F877A->setText("1");

        ui->lineBit0_16F877A->setText("TX9D");
        ui->lineBit1_16F877A->setText("TRMT");
        ui->lineBit2_16F877A->setText("BRGH");
        ui->lineBit3_16F877A->setText("---");
        ui->lineBit4_16F877A->setText("SYNC");
        ui->lineBit5_16F877A->setText("TXEN");
        ui->lineBit6_16F877A->setText("TX9");
        ui->lineBit7_16F877A->setText("CSRC");

        ui->textConfig_16F877A->setText("--- = Unimplemented: Read as '0'\n\n"

                                "CSRC: Clock Source Select bit\n"
                                "\tAsychronous mode:\n"
                                "\tDon't care.\n\n"

                                "\tSychronous mode:\n"
                                "\t1 = Master mode (clock generated internally from BRG)\n"
                                "\t0 = Slave mode (clock from external source)\n\n"

                                "TX9: 9-bit Transmit Enable bit\n"
                                "\t1 = Selects 9-bit transmission\n"
                                "\t0 = Selects 8-bit transmission\n\n"

                                "TXEN: Transmit Enable bit\n"
                                "\t1 = Transmit enabled\n"
                                "\t0 = Transmit disabled\n\n"

                                "Note: SREN/CREN overrides TXEN in Sync mode.\n\n"

                                "SYNC: USART Mode Select bit\n"
                                "\t1 = Synchronous mode\n"
                                "\t0 = Asynchronous mode\n\n"

                                "BRGH: High Baud Rate Select bit\n"
                                "\tAsychronous mode:\n"
                                "\t1 = High speed\n"
                                "\t0 = Low speed\n\n"

                                "\tSychronous mode:\n"
                                "\tUnused in this mode.\n\n"

                                "TRMT: Transmit Shift Register Status bit\n"
                                "\t1 = TSR empty\n"
                                "\t0 = TSR full\n\n"

                                "TX9D: 9th bit of Transmit Data, can be Parity bit");
    }

    else if (contenuCombo == "RCSTA")
    {
        ui->lineNameSign_16F877A->setText(" Receive STAtus and Control register");
        ui->lineAddr_16F877A->setText("18h");
        ui->lineBank_16F877A->setText("0");

        ui->lineBit0_16F877A->setText("RX9D");
        ui->lineBit1_16F877A->setText("OERR");
        ui->lineBit2_16F877A->setText("FERR");
        ui->lineBit3_16F877A->setText("ADDEN");
        ui->lineBit4_16F877A->setText("CREN");
        ui->lineBit5_16F877A->setText("SREN");
        ui->lineBit6_16F877A->setText("RX9");
        ui->lineBit7_16F877A->setText("SPEN");

        ui->textConfig_16F877A->setText("SPEN: Serial Port Enable bit\n"
                                "\t1 = Serial port enabled (configures RC7/RX/DT and RC6/TX/CK pins as serial port pins)\n"
                                "\t0 = Serial port disabled\n\n"

                                "\tRX9: 9-bit Receive Enable bit\n"
                                "\t1 = Selects 9-bit reception\n"
                                "\t0 = Selects 8-bit reception\n\n"

                                "SREN: Single Receive Enable bit\n"
                                "\tAsychronous mode:\n"
                                "\tDon't care.\n\n"

                                "\tSychronous mode Master:\n"
                                "\t1 = Enables single receive\n"
                                "\t0 = Disables single receive; This bit is cleared after reception is complete.\n\n"

                                "\tSynchronous mode Slave:\n"
                                "\tDon't care.\n\n"

                                "CREN: Continuous Receive Enable bit\n"
                                "\tAsychronous mode:\n"
                                "\t1 = Enables continuous receive\n"
                                "\t0 = Disables continuous receive\n\n"

                                "\tSychronous mode Master:\n"
                                "\t1 = Enables continuous receive until enable bit CREN is cleared (CREN overrides SREN)\n"
                                "\t0 = Disables continuous receive\n\n"

                                "ADDEN: Address Detect Enable bit\n"
                                "\tAsynchronous mode 9-bit (RX9 = 1):\n"
                                "\t1 = Enables address detection, enables interrupt and load of the receive buffer when RSR<8> is set\n"
                                "\t0 = Disables address detection, all bytes are received and ninth bit can be used as parity bit\n\n"

                                "FERR: Framing Error bit\n"
                                "\t1 = Framing error (can be updated by reading RCREG register and receive next valid byte)\n"
                                "\t0 = No framing error\n\n"

                                "OERR: Overrun Error bit\n"
                                "\t1 = Overrun error (can be cleared by clearing bit CREN)\n"
                                "\t0 = No overrun error\n\n"

                                "RX9D: 9th bit of Received Data (can be parity bit but must be calculated by user firmware)");
    }

    else if (contenuCombo == "EECON1")
    {
        ui->lineNameSign_16F877A->setText("Electrically Erasable PROM CONtrol register");
        ui->lineAddr_16F877A->setText("18Ch");
        ui->lineBank_16F877A->setText("3");

        ui->lineBit0_16F877A->setText("RD");
        ui->lineBit1_16F877A->setText("WR");
        ui->lineBit2_16F877A->setText("WREN");
        ui->lineBit3_16F877A->setText("WRERR");
        ui->lineBit4_16F877A->setText("---");
        ui->lineBit5_16F877A->setText("---");
        ui->lineBit6_16F877A->setText("---");
        ui->lineBit7_16F877A->setText("EEPGD");

        ui->textConfig_16F877A->setText("--- = Unimplemented: Read as '0'\n\n"

                                "EEPGD: Program/Data EEPROM Select bit\n"
                                "\t1 = Accesses program memory\n"
                                "\t0 = Accesses data memory; Reads '0' after a POR\n"
                                "\tThis bit cannot be changed while a write operation is in progress.\n\n"

                                "WRERR: EEPROM Error Flag bit\n"
                                "\t1 = A write operation is prematurely terminated (any MCLR or any WDT Reset during normal operation)\n"
                                "\t0 = The write operation completed\n\n"

                                "WREN: EEPROM Write Enable bit\n"
                                "\t1 = Allows write cycles\n"
                                "\t0 = Inhibits write to the EEPROM\n\n"

                                "WR: Write Control bit\n"
                                "\t1 = Initiates a write cycle. The bit is cleared by hardware once write is complete.\n"
                                "\tThe WR bit can only be set (not cleared) in software.\n"

                                "\t0 = Write cycle to the EEPROM is complete\n\n"

                                "RD: Read Control bit\n"
                                "\t1 = Initiates an EEPROM read; RD is cleared in hardware.\n"
                                "\tThe RD bit can only be set (not cleared) in software.\n"
                                "\t0 = Does not initiate an EEPROM read");
    }

    else if (contenuCombo == "ADCON0")
    {
        ui->lineNameSign_16F877A->setText("Analogic-to-Digital CONverter0 register");
        ui->lineAddr_16F877A->setText("1Fh");
        ui->lineBank_16F877A->setText("0");

        ui->lineBit0_16F877A->setText("ADON");
        ui->lineBit1_16F877A->setText("---");
        ui->lineBit2_16F877A->setText("GO/#DONE");
        ui->lineBit3_16F877A->setText("CHS0");
        ui->lineBit4_16F877A->setText("CHS1");
        ui->lineBit5_16F877A->setText("CHS2");
        ui->lineBit6_16F877A->setText("ADCS0");
        ui->lineBit7_16F877A->setText("ADCS1");

        ui->textConfig_16F877A->setText("--- = Unimplemented: Read as '0'\n\n"

                                "ADCS1:ADCS0: A/D Conversion Clock Select bits\n\n"

                                "ADCON1    \tADCON0          \tClock Conversion\n"
                                "<ADCS2>    \t<ADCS1:ADCS0>\n"
                                "0       \t00                   \tFosc/2\n"
                                "0       \t01                   \tFosc/8\n"
                                "0       \t10                   \tFosc/32\n"
                                "0       \t11                   \tFRC (clock derived from the internal A/D RC oscillator)\n"
                                "1       \t00                   \tFosc/4\n"
                                "1       \t01                   \tFosc/16\n"
                                "1       \t10                   \tFosc/64\n"
                                "1       \t11                   \tFRC (clock derived from the internal A/D RC oscillator)\n\n"

                                "CHS2:CHS0: Analog Channel Select bits\n"
                                "\t000 = Channel 0 (AN0)\n"
                                "\t001 = Channel 1 (AN1)\n"
                                "\t010 = Channel 2 (AN2)\n"
                                "\t011 = Channel 3 (AN3)\n"
                                "\t100 = Channel 4 (AN4)\n"
                                "\t101 = Channel 5 (AN5)\n"
                                "\t110 = Channel 6 (AN6)\n"
                                "\t111 = Channel 7 (AN7)\n\n"

                                "Note: The PIC(R) 16F873A/876A devices only implement A/D channels 0 through 4;\n"
                                "the unimplemented selections are reserved.\n"
                                "Do not select any unimplemented channels with these devices.\n\n"

                                "GO/#DONE: A/D Conversion Status bit\n"
                                "\tWhen ADON = 1:\n"
                                "\t1 = A/D conversion in progress (setting this bit starts the A/D conversion which is automatically\n"
                                "\tcleared by hardware when the A/D conversion is complete)\n"

                                "\t0 = A/D conversion not in progress\n\n"

                                "ADON: A/D On bit\n"
                                "\t1 = A/D converter module is powered up\n"
                                "\t0 = A/D converter module is shut-off and consumes no operating current\n");
    }

    else if (contenuCombo == "ADCON1")
    {
        ui->lineNameSign_16F877A->setText("Analogic-to-Digital CONverter1 register");
        ui->lineAddr_16F877A->setText("9Fh");
        ui->lineBank_16F877A->setText("1");

        ui->lineBit0_16F877A->setText("PCFG0");
        ui->lineBit1_16F877A->setText("PCFG1");
        ui->lineBit2_16F877A->setText("PCFG2");
        ui->lineBit3_16F877A->setText("PCFG3");
        ui->lineBit4_16F877A->setText("---");
        ui->lineBit5_16F877A->setText("---");
        ui->lineBit6_16F877A->setText("ADCS2");
        ui->lineBit7_16F877A->setText("ADFM");

        ui->textConfig_16F877A->setText("--- = Unimplemented: Read as '0'\n\n"

                                "ADFM: A/D Result Format Select bit\n"
                                "\t1 = Right justified. Six (6) Most Significant bits of ADRESH are read as '0'.\n"
                                "\t0 = Left justified. Six (6) Least Significant bits of ADRESL are read as '0'.\n\n"

                                "ADCS2: A/D Conversion Clock Select bit\n\n"

                                "ADCON1    \tADCON0          \tClock Conversion\n"
                                "<ADCS2>    \t<ADCS1:ADCS0>\n"
                                "0       \t00                   \tFosc/2\n"
                                "0       \t01                   \tFosc/8\n"
                                "0       \t10                   \tFosc/32\n"
                                "0       \t11                   \tFRC (clock derived from the internal A/D RC oscillator)\n"
                                "1       \t00                   \tFosc/4\n"
                                "1       \t01                   \tFosc/16\n"
                                "1       \t10                   \tFosc/64\n"
                                "1       \t11                   \tFRC (clock derived from the internal A/D RC oscillator)\n\n"

                                "PCFG3:PCFG0: A/D Port Configuration Control bits\n\n"
                                "PCFG3:0 \tAN7 \tAN6 \tAN5 \tAN4 \tAN3 \tAN2     \tAN1 \tAN0 \tVref+ \tVref-  \tCR \n\n"

                                "0000    \tA   \tA   \tA   \tA   \tA      \tA     \tA   \tA   \tVDD   \tVSS   \t8/0 \n"
                                "0001    \tA   \tA   \tA   \tA   \tVref+  \tA     \tA   \tA   \tAN3   \tVSS   \t7/1 \n"
                                "0010    \tD   \tD   \tD   \tA   \tA      \tA     \tA   \tA   \tVDD   \tVSS   \t5/0 \n"
                                "0011    \tD   \tD   \tD   \tA   \tVref+  \tA     \tA   \tA   \tAN3   \tVSS   \t4/1 \n"
                                "0100    \tD   \tD   \tD   \tD   \tA      \tD     \tA   \tA   \tVDD   \tVSS   \t3/0 \n"
                                "0101    \tD   \tD   \tD   \tD   \tVref+  \tD     \tA   \tA   \tAN3   \tVSS   \t2/1 \n"
                                "011x    \tD   \tD   \tD   \tD   \tD      \tD     \tD   \tD   \t ---- \t ---- \t0/0 \n"
                                "1000    \tA   \tA   \tA   \tA   \tVref+  \tVref- \tA   \tA   \tAN3   \tAN2   \t6/2 \n"
                                "1001    \tD   \tD   \tA   \tA   \tA      \tA     \tA   \tA   \tVDD   \tVSS   \t6/0 \n"
                                "1010    \tD   \tD   \tA   \tA   \tVref+  \tA     \tA   \tA   \tAN3   \tVSS   \t5/1 \n"
                                "1011    \tD   \tD   \tA   \tA   \tVref+  \tVref- \tA   \tA   \tAN3   \tAN2   \t4/2 \n"
                                "1100    \tD   \tD   \tD   \tA   \tVref+  \tVref- \tA   \tA   \tAN3   \tAN2   \t3/2 \n"
                                "1101    \tD   \tD   \tD   \tD   \tVref+  \tVref- \tA   \tA   \tAN3   \tAN2   \t2/2 \n"
                                "1110    \tD   \tD   \tD   \tD   \tD      \tD     \tD   \tA   \tVDD   \tVSS   \t1/0 \n"
                                "1111    \tD   \tD   \tD   \tD   \tVref+  \tVref- \tD   \tA   \tAN3   \tAN2   \t1/2 \n\n"

                                "A = Analog input D = Digital I/O\n"
                                "x = Bit is unknown\n"
                                "C/R = # of analog input channels/# of A/D voltage references");
    }

    else if (contenuCombo == "CMCON")
    {
        ui->lineNameSign_16F877A->setText("Comparator Module CONtrol register");
        ui->lineAddr_16F877A->setText("9Ch");
        ui->lineBank_16F877A->setText("1");

        ui->lineBit0_16F877A->setText("CM0");
        ui->lineBit1_16F877A->setText("CM1");
        ui->lineBit2_16F877A->setText("CM2");
        ui->lineBit3_16F877A->setText("CIS");
        ui->lineBit4_16F877A->setText("C1INV");
        ui->lineBit5_16F877A->setText("C2INV");
        ui->lineBit6_16F877A->setText("C1OUT");
        ui->lineBit7_16F877A->setText("C2OUT");

        ui->textConfig_16F877A->setText(

                    "C2OUT: Comparator 2 Output bit\n"
                    "\tWhen C2INV = 0:\n"
                    "\t1 = C2 VIN+ > C2 VIN-\n"
                    "\t0 = C2 VIN+ < C2 VIN-\n\n"

                    "\tWhen C2INV = 1:\n"
                    "\t1 = C2 VIN+ < C2 VIN-\n"
                    "\t0 = C2 VIN+ > C2 VIN-\n\n"

                    "C1OUT: Comparator 1 Output bit\n"
                    "\tWhen C1INV = 0:\n"
                    "\t1 = C1 VIN+ > C1 VIN-\n"
                    "\t0 = C1 VIN+ < C1 VIN-\n\n"

                    "\tWhen C1INV = 1:\n"
                    "\t1 = C1 VIN+ < C1 VIN-\n"
                    "\t0 = C1 VIN+ > C1 VIN-\n\n"

                    "C2INV: Comparator 2 Output Inversion bit\n"
                    "\t1 = C2 output inverted\n"
                    "\t0 = C2 output not inverted\n\n"

                    "C1INV: Comparator 1 Output Inversion bit\n"
                    "\t1 = C1 output inverted\n"
                    "\t0 = C1 output not inverted\n\n"

                    "CIS: Comparator Input Switch bit\n"
                    "\tWhen CM2:CM0 = 110:\n"
                    "\t1 = C1 VIN- connects to RA3/AN3; C2 VIN- connects to RA2/AN2\n"
                    "\t0 = C1 VIN- connects to RA0/AN0; C2 VIN- connects to RA1/AN1\n\n"

                    "CM2:CM0: Comparator Mode bits\n"
                    "\tFIGURES ARE TOO BIG FOR THIS APPLICATION WINDOW, See Microchip's(R) 16F877A Datasheet(2003), Page 136.\n"
                    "\tFigure 12-1 shows the Comparator modes and CM2:CM0 bit settings.");
    }

    else if (contenuCombo == "CVRCON")
    {
        ui->lineNameSign_16F877A->setText("Comparator Voltage Reference CONtrol register");
        ui->lineAddr_16F877A->setText("9Dh");
        ui->lineBank_16F877A->setText("1");

        ui->lineBit0_16F877A->setText("CVR0");
        ui->lineBit1_16F877A->setText("CVR1");
        ui->lineBit2_16F877A->setText("CVR2");
        ui->lineBit3_16F877A->setText("CVR3");
        ui->lineBit4_16F877A->setText("---");
        ui->lineBit5_16F877A->setText("CVRR");
        ui->lineBit6_16F877A->setText("CVROE");
        ui->lineBit7_16F877A->setText("CVREN");

        ui->textConfig_16F877A->setText("--- = Unimplemented: Read as '0'\n\n"

                                "CVREN: Comparator Voltage Reference Enable bit\n"
                                "\t1 = CVREF circuit powered on\n"
                                "\t0 = CVREF circuit powered down\n\n"

                                "CVROE: Comparator VREF Output Enable bit\n"
                                "\t1 = CVREF voltage level is output on RA2/AN2/VREF-/CVREF pin\n"
                                "\t0 = CVREF voltage level is disconnected from RA2/AN2/VREF-/CVREF pin\n\n"

                                "CVRR: Comparator VREF Range Selection bit\n"
                                "\t1 = 0 to 0.75 CVRSRC, with CVRSRC/24 step size\n"
                                "\t0 = 0.25 CVRSRC to 0.75 CVRSRC, with CVRSRC/32 step size\n\n"

                                "CVR3:CVR0: Comparator VREF Value Selection bits 0 <= VR3:VR0 <= 15\n"
                                "\tWhen CVRR = 1:\n"
                                "\tCVREF = (VR<3:0>/ 24) * (CVRSRC)\n"

                                "\tWhen CVRR = 0:\n"
                                "\tCVREF = 1/4 * (CVRSRC) + (VR3:VR0/ 32) * (CVRSRC)");
    }

}
//##############################################################################################################
void PicClass::browse_16F84A()
{
    QString contenuCombo;
    contenuCombo = ui->boxRegName_16F84A->currentText();

    if (contenuCombo == ">>> List Box <<<")
    {
        ui->lineNameSign_16F84A->clear();
        ui->lineAddr_16F84A->clear();
        ui->lineBank_16F84A->clear();

        ui->lineBit0_16F84A->clear();
        ui->lineBit1_16F84A->clear();
        ui->lineBit2_16F84A->clear();
        ui->lineBit3_16F84A->clear();
        ui->lineBit4_16F84A->clear();
        ui->lineBit5_16F84A->clear();
        ui->lineBit6_16F84A->clear();
        ui->lineBit7_16F84A->clear();

        ui->textConfig_16F84A->setText("\n\n\n\n\t\tPlease, Select a register name in the List Box!");
    }
    else if (contenuCombo == "STATUS")
    {
        ui->lineNameSign_16F84A->setText("Status register");
        ui->lineAddr_16F84A->setText("03h ; 83h");
        ui->lineBank_16F84A->setText("0 ; 1");

        ui->lineBit0_16F84A->setText("C");
        ui->lineBit1_16F84A->setText("DC");
        ui->lineBit2_16F84A->setText("Z");
        ui->lineBit3_16F84A->setText("#PD");
        ui->lineBit4_16F84A->setText("#TO");
        ui->lineBit5_16F84A->setText("RP0");
        ui->lineBit6_16F84A->setText("RP1");
        ui->lineBit7_16F84A->setText("IRP");

        ui->textConfig_16F84A->setText("IRP:RP1: Unimplemented, maintain as 0 (zero)\n\n"

                                "RP0: Register Bank Select bits (used for direct addressing)\n"
                                "\t01 = Bank 1 (80h - FFh)\n"
                                "\t00 = Bank 0 (00h - 7Fh)\n"
                                "\tEach bank is 128 bytes.\n\n"

                                "#TO: Time-out bit\n"
                                "\t1 = After power-up, CLRWDT instruction or SLEEP instruction\n"
                                "\t0 = A WDT time-out occurred\n\n"

                                "#PD: Power-down bit\n"
                                "\t1 = After power-up or by the CLRWDT instruction\n"
                                "\t0 = By execution of the SLEEP instruction\n\n"

                                "Z: Zero bit\n"
                                "\t1 = The result of an arithmetic or logic operation is zero\n"
                                "\t0 = The result of an arithmetic or logic operation is not zero\n\n"

                                "DC: Digit carry/#borrow bit (ADDWF, ADDLW,SUBLW,SUBWF instructions)(for #borrow, the polarity is reversed)\n"
                                "\t1 = A carry-out from the 4th low order bit of the result occurred\n"
                                "\t0 = No carry-out from the 4th low order bit of the result\n\n"

                                "C: Carry/#borrow bit (ADDWF, ADDLW,SUBLW,SUBWF instructions)(for #borrow, the polarity is reversed)\n"
                                "\t1 = A carry-out from the Most Significant bit of the result occurred\n"
                                "\t0 = No carry-out from the Most Significant bit of the result occurred");
    }
    //||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
    else if (contenuCombo == "CONFIGURATION WORD")
    {
        PicClass::autreReg16F84A("CONFIGURATION WORD");
    }
    //||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
    else if (contenuCombo == "SFR Banks")
    {
        PicClass::autreReg16F84A("SFR Banks");
    }

    else if (contenuCombo == "OPTION_REG")
    {
        ui->lineNameSign_16F84A->setText("OPTION REGister");
        ui->lineAddr_16F84A->setText("81h");
        ui->lineBank_16F84A->setText("1");

        ui->lineBit0_16F84A->setText("PS0");
        ui->lineBit1_16F84A->setText("PS1");
        ui->lineBit2_16F84A->setText("PS2");
        ui->lineBit3_16F84A->setText("PSA");
        ui->lineBit4_16F84A->setText("T0SE");
        ui->lineBit5_16F84A->setText("T0CS");
        ui->lineBit6_16F84A->setText("INTEDG");
        ui->lineBit7_16F84A->setText("#RBPU");

        ui->textConfig_16F84A->setText("#RBPU: PORTB Pull-up Enable bit\n"
                                "\t1 = PORTB pull-ups are disabled\n"
                                "\t0 = PORTB pull-ups are enabled by individual port latch values\n\n"

                                "INTEDG: Interrupt Edge Select bit\n"
                                "\t1 = Interrupt on rising edge of RB0/INT pin\n"
                                "\t0 = Interrupt on falling edge of RB0/INT pin\n\n"

                                "T0CS: TMR0 Clock Source Select bit\n"
                                "\t1 = Transition on RA4/T0CKI pin\n"
                                "\t0 = Internal instruction cycle clock (CLKO)\n\n"

                                "T0SE: TMR0 Source Edge Select bit\n"
                                "\t1 = Increment on high-to-low transition on RA4/T0CKI pin\n"
                                "\t0 = Increment on low-to-high transition on RA4/T0CKI pin\n\n"

                                "PSA: Prescaler Assignment bit\n"
                                "\t1 = Prescaler is assigned to the WDT\n"
                                "\t0 = Prescaler is assigned to the Timer0 module\n\n"

                                "PS2:PS0: Prescaler Rate Select bits\n"
                                "\tBit Value\tTMR0 Rate\tWDT Rate\n"
                                "\t000\t1:2\t1:1\n"
                                "\t001\t1:4\t1:2\n"
                                "\t010\t1:8\t1:4\n"
                                "\t011\t1:16\t1:8\n"
                                "\t100\t1:32\t1:16\n"
                                "\t101\t1:64\t1:32\n"
                                "\t110\t1:128\t1:64\n"
                                "\t111\t1:256\t1:128");

    }

    else if (contenuCombo == "INTCON")
    {
        ui->lineNameSign_16F84A->setText("INTerrupts CONtrol register");
        ui->lineAddr_16F84A->setText("0Bh ; 8Bh");
        ui->lineBank_16F84A->setText("0 ; 1");

        ui->lineBit0_16F84A->setText("RBIF");
        ui->lineBit1_16F84A->setText("INTF");
        ui->lineBit2_16F84A->setText("T0IF");
        ui->lineBit3_16F84A->setText("RBIE");
        ui->lineBit4_16F84A->setText("INTE");
        ui->lineBit5_16F84A->setText("T0IE");
        ui->lineBit6_16F84A->setText("EEIE");
        ui->lineBit7_16F84A->setText("GIE");

        ui->textConfig_16F84A->setText("GIE: Global Interrupt Enable bit\n"
                                "\t1 = Enables all unmasked interrupts\n"
                                "\t0 = Disables all interrupts\n\n"

                                "EEIE: EE Write Complete Interrupt Enable bit\n"
                                "\t1 = Enables the EE Write Complete interrupts\n"
                                "\t0 = Disables the EE Write Complete interrupts\n\n"

                                "T0IE: TMR0 Overflow Interrupt Enable bit\n"
                                "\t1 = Enables the TMR0 interrupt\n"
                                "\t0 = Disables the TMR0 interrupt\n\n"

                                "INTE: RB0/INT External Interrupt Enable bit\n"
                                "\t1 = Enables the RB0/INT external interrupt\n"
                                "\t0 = Disables the RB0/INT external interrupt\n\n"

                                "RBIE: RB Port Change Interrupt Enable bit\n"
                                "\t1 = Enables the RB port change interrupt\n"
                                "\t0 = Disables the RB port change interrupt\n\n"

                                "T0IF: TMR0 Overflow Interrupt Flag bit\n"
                                "\t1 = TMR0 register has overflowed (must be cleared in software)\n"
                                "\t0 = TMR0 register did not overflow\n\n"

                                "INTF: RB0/INT External Interrupt Flag bit\n"
                                "\t1 = The RB0/INT external interrupt occurred (must be cleared in software)\n"
                                "\t0 = The RB0/INT external interrupt did not occur\n\n"

                                "RBIF: RB Port Change Interrupt Flag bit\n"
                                "\t1 = At least one of the RB7:RB4 pins changed state; a mismatch condition will continue to set the "
                                "bit (must be cleared in software).\n"
                                "\t0 = None of the RB7:RB4 pins have changed state");


    }

    else if (contenuCombo == "EECON1")
    {
        ui->lineNameSign_16F84A->setText("EEPROM read and write operations CONtrol register");
        ui->lineAddr_16F84A->setText("88h");
        ui->lineBank_16F84A->setText("1");

        ui->lineBit0_16F84A->setText("RD");
        ui->lineBit1_16F84A->setText("WR");
        ui->lineBit2_16F84A->setText("WREN");
        ui->lineBit3_16F84A->setText("WRERR");
        ui->lineBit4_16F84A->setText("EEIF");
        ui->lineBit5_16F84A->setText("---");
        ui->lineBit6_16F84A->setText("---");
        ui->lineBit7_16F84A->setText("---");

        ui->textConfig_16F84A->setText("Bits 7:5: Unimplemented, read as 0 (zero)\n\n"

                                "EEIF: EEPROM Write Operation Interrupt Flag bit\n"
                                "\t1 = The Write operation completed (must be cleared in software)\n"
                                "\t0 = The Write operation is not complete or has not been started\n\n"

                                "WRERR: EEPROM Error Flag bit\n"
                                "\t1 = A write operation is prematurely terminated (any #MCLR Reset or any WDT Reset during normal operation)\n"
                                "\t0 = The write operation completed\n\n"

                                "WREN: EEPROM Write Enable bit\n"
                                "\t1 = Allows write cycles\n"
                                "\t0 = Inhibits write to the EEPROM\n\n"

                                "WR: Write control bit\n"
                                "\t1 = Initiates a write cycle. The bit is cleared by hardware once write is complete. The WR bit can only be set (not cleared) in software.\n"
                                "\t0 = Write cycle to EEPROM is complete\n\n"

                                "RD: Read control bit\n"
                                "\t1 = Initiates an EEPROM read. RD is cleared in hardware. The RD bit can only be set (not cleared) in software.\n"
                                "\t0 = Does not initiate an EEPROM read");

    }


}
//##############################################################################################################
PicClass::~PicClass()
{
    delete ui;
}

void PicClass::changeEvent(QEvent *e)
{
    QMainWindow::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}
//##############################################################################################################
